<?php
/**
 * Load all active Clips.
 * 
 * @package WP_Clips/Includes
 * @subpackage Loader
 */


class WP_Clips_Loader {


	public function __construct() {

		add_action( 'after_setup_theme', [ $this, 'clips_load' ], 5 );
	}

	/**
	 * Load all active Clips
	 * @since 3.0
	 */

	// Load after theme
	public function clips_load() {

		// Include core Clip functions
		$file = WP_CLIPS_DIR . 'clip-core/core-functions.php';
		if( file_exists( $file ) ) include( $file );

		// Load admin Clips (if any)
		if( is_admin() )
			foreach( glob( WP_CLIPS_PREC . 'clip-*/admin-functions.php', GLOB_NOSORT ) as $file ) {
				if( file_exists( $file ) ) include( $file );
			}

		// Load precoded Clips (if any)
		foreach( glob( WP_CLIPS_PREC . 'clip-*/clip-functions.php', GLOB_NOSORT ) as $file ) {
			if( file_exists( $file ) ) include( $file );
		}

		// Load custom functions (if active)
		$file = WP_CLIPS_DIR . 'clip-custom/custom-functions.php';
		if( ! file_exists( $file ) ) return;

		include( $file );

		// Enqueue custom script and stylesheet (if exists)
		add_action( 'wp_enqueue_scripts', function() {

			$file = 'clip-custom/custom-script.js';
			if( file_exists( WP_CLIPS_DIR . $file ) )
				wp_enqueue_script( 'clip-custom-script', content_url( 'clips/' . $file ),
									['jquery'], WP_CLIPS_VERS, true
					);

			$file = 'clip-custom/custom-style.css';
			if( file_exists( WP_CLIPS_DIR . $file ) )
				wp_enqueue_style(  'clip-custom-style', content_url( 'clips/' . $file ),
									[], WP_CLIPS_VERS
					);
		}, 15 );
	}	
}

new WP_Clips_Loader();